clear

warning off MATLAB:divideByZero;
warning off MATLAB:singularMatrix;
warning off MATLAB:rankDeficientMatrix;

format compact;
format short g;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
%%%%%%%%%%%%%%%%%%%%%%% MARGINAL EFFECTS FOR PANEL DATA DYNAMIC DISCRETE CHOICE MODELS %%%%%%%%%%%%%%%%%%%%%%%%;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
% APPLICATION: WOMEN LABOR FORCE PARTICIPATION;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;
% dstar_{it} =  x_{it}' \beta + \alpha_2{i} - \epsilon2_{it};
% d_{it} = 1{dstar_{it} > 0};
% Variables;
%   1.- d = dummy for welfare participation (=1 for participants);
%   2.- Regressors: asssumed predetermined ;
%       i) Specification 1 ;
%           1.- lag of d;
%       ii) Specification 3 ;
%           1.- kids1: # of kids < 2;
%           2.- kids2: # of 2 < kids < 6;
%           3.- kids3: # of kids > 6;
%           4.- lhusb_income : log(husband_income) (1995 $);
%           5.- age;
%           6.- age^2;
%       iii) Specification 2 ;
%           7.- 8 Time dummies (omitted for first period = 1980);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%;

% VALUES OF THE PARAMETERS;

B = 1;
T = 9; % Includes year used as initial condition for the lagged dependent variable
specification = 3; % chooses specification;

% LOADING DATASET;

load('z:\marginal_effects\applications\LFP3\data\lfp_psid_fs.txt','-ascii'); % Full sample
load('z:\marginal_effects\applications\LFP3\data\lfp_psid.txt','-ascii');    % Sample excluding individuals that do not change status
N = size(lfp_psid_fs,1)/T;
Np = size(lfp_psid,1)/T;

clog = sqrt(3) / pi;
cprob = pi / sqrt(3);
options = optimset('GradObj','on');


%options = optimset('GradObj','on');

% ESTIMATION;

tic,
for i = 1:B,

    disp(i);

% CONSTRUCTING MATRICES OF DATA;

    if specification == 1,
        p2 = 1; % number of explanatory variables (including lagged dependent variable, excluding fixed effects
        x2 = [lfp_psid(1:Np*T,4)];
        x2_y0 = [zeros(Np*T,1)];
        x2_y1 = [ones(Np*T,1)];
        x2_fs = [lfp_psid_fs(:,4)];
        x2_y0_fs = [zeros(N*T,1)];
        x2_y1_fs = [ones(N*T,1)];
    elseif specification == 3,
        p2 = 6;  % number of explanatory variables (excluding fixed effects
        x2 = [lfp_psid(1:Np*T,5:10)];
        x2_y0 = [lfp_psid(1:Np*T,5:10)];
        x2_y1 = [lfp_psid(1:Np*T,5:10)];
        x2_fs = [lfp_psid_fs(:,5:10)];
        x2_y0_fs = [lfp_psid_fs(:,5:10)];
        x2_y1_fs = [lfp_psid_fs(:,5:10)];
    else,
        p2 = 14;  % number of explanatory variables (excluding fixed effects
        x2 = [lfp_psid(1:Np*T,5:18)];
        x2_y0 = [lfp_psid(1:Np*T,5:18)];
        x2_y1 = [lfp_psid(1:Np*T,5:18)];
        x2_fs = [lfp_psid_fs(:,5:18)];
        x2_y0_fs = [lfp_psid_fs(:,5:18)];
        x2_y1_fs = [lfp_psid_fs(:,5:18)];
    end;

    d = lfp_psid(1:Np*T,3);
    d_fs = lfp_psid_fs(1:N*T,3);
    clear lfp_psid_fs;
   
  
    x2bar_fs(:,i) = mean(x2_fs)';
    s2x2bar_fs = cov(x2_fs,1) / size(x2_fs,1);
    x2bar_y0_fs(:,i) = mean(x2_y0_fs)';
    s2x2bar_y0_fs = cov(x2_y0_fs,1) / size(x2_y0_fs,1);
    x2bar_y1_fs(:,i) = mean(x2_y1_fs)';
    s2x2bar_y1_fs = cov(x2_y1_fs,1) / size(x2_y1_fs,1);
    
%    clear x2_fs;
    clear x2_y0_fs;
    clear x2_y1_fs;
    clear lfp_psid;

% MATRICES FOR FIXED EFFECTS;
D = kron([1:N]',ones(T,1));
X2 = [x2_fs,sparse(dummyvar(D))];

% LPM: FIXED EFFECTS LINEAR PROBABILITY MODEL (FULL SAMPLE);
    delta = X2\d_fs;
       
    H_lpm = vc_olsen(d_fs,X2,delta,D);
    betahatlpm(:,i) = delta(1:p2,1);
    s2hat_lpm(:,i) = diag(H_lpm(1:p2,1:p2));
    
    mulpm = X2*delta;
       
    meffhatlpm_fs(:,i) = betahatlpm(:,i);
    ameffhatlpm_fs(:,i) = betahatlpm(:,i);
    s2hat_meff_lpm_fs(:,i) = s2hat_lpm(:,i);
    s2hat_ameff_lpm_fs(:,i) = s2hat_lpm(:,i);

    meff2hatlpm_fs(i) = betahatlpm(1,i);
    ameff2hatlpm_fs(i) = betahatlpm(1,i);
    s2hat_meff2_lpm_fs(i) = s2hat_lpm(1,i);
    s2hat_ameff2_lpm_fs(i) = s2hat_lpm(1,i);
    
    clear H_lpm;

% BC LPM (FULL SAMPLE);    
    biasbetahatlpm(:,i) = bias_beta_olsen(d_fs,X2,delta,N,D);
    betahatlpmbc(:,i) = betahatlpm(:,i) - (1/T)*biasbetahatlpm(:,i);
    delbc = sparse(dummyvar(D))\(d_fs-x2_fs*betahatlpmbc(:,i));
    deltabc = [betahatlpmbc(:,i); delbc];
    H_lpmbc = vc_olsen(d_fs,X2,deltabc,D);
    s2hat_lpmbc(:,i) = diag(H_lpmbc(1:p2,1:p2));
    
    mulpmbc = X2*deltabc;
    
    meffhatlpmbc(:,i) = betahatlpmbc(:,i);
    ameffhatlpmbc(:,i) = betahatlpmbc(:,i);
    s2hat_meff_lpmbc(:,i) = s2hat_lpmbc(:,i);
    s2hat_ameff_lpmbc(:,i) = s2hat_lpmbc(:,i);
    
    meffhatlpmbc_fs(:,i) = betahatlpmbc(:,i);
    ameffhatlpmbc_fs(:,i) = betahatlpmbc(:,i);
    s2hat_meff_lpmbc_fs(:,i) = s2hat_lpmbc(:,i);
    s2hat_ameff_lpmbc_fs(:,i) = s2hat_lpmbc(:,i);

    meff2hatlpmbc_fs(i) = betahatlpmbc(1,i);
    ameff2hatlpmbc_fs(i) = betahatlpmbc(1,i);
    s2hat_meff2_lpmbc_fs(i) = s2hat_lpmbc(1,i);
    s2hat_ameff2_lpmbc_fs(i) = s2hat_lpmbc(1,i);
    
    clear H_lpmbc;
    
clear x2_fs;
    
% MATRICES FOR FIXED EFFECTS;
D = kron([1:Np]',ones(T,1));
FE = sparse(dummyvar(D));

    
% ELIMINATING INDIVIDUALS WITH ALL 1's OR 0's;
    x2p = x2;
    x2p_y0 = x2_y0;
    x2p_y1 = x2_y1;
    FEp = FE;
    Dp = D;

    X2 = sparse([x2p,FEp]);
    X2_y0 = sparse([x2p_y0,FEp]);
    X2_y1 = sparse([x2p_y1,FEp]);
    

    nobs1(i) = T*Np;
%    init = X2\d;


% FIXED EFFECTS ADJUSTED LINEAR PROBABILITY MODEL;
    delta = X2\d;
    
    H_olsen = vc_olsen(d,X2,delta,Dp);
    betahatolsen(:,i) = delta(1:p2,1);
    s2hat_olsen(:,i) = diag(H_olsen(1:p2,1:p2));
    
    muolsen = X2*delta;
    
    meffhatolsen(:,i) = betahatolsen(:,i);
    ameffhatolsen(:,i) = betahatolsen(:,i);
    s2hat_meff_olsen(:,i) = s2hat_olsen(:,i);
    s2hat_ameff_olsen(:,i) = s2hat_olsen(:,i);
    
    meffhatolsen_fs(:,i) = (Np/N)*betahatolsen(:,i);
    ameffhatolsen_fs(:,i) = (Np/N)*betahatolsen(:,i);
    s2hat_meff_olsen_fs(:,i) = ((Np/N)^2)*s2hat_olsen(:,i);
    s2hat_ameff_olsen_fs(:,i) = ((Np/N)^2)*s2hat_olsen(:,i);

    meff2hatolsen_fs(i) = (Np/N)*betahatolsen(1,i);
    ameff2hatolsen_fs(i) = (Np/N)*betahatolsen(1,i);
    s2hat_meff2_olsen_fs(i) = ((Np/N)^2)*s2hat_olsen(1,i);
    s2hat_ameff2_olsen_fs(i) = ((Np/N)^2)*s2hat_olsen(1,i);

% BC ADJUSTED LPM;    
    biasbetahatolsen(:,i) = bias_beta_olsen(d,X2,delta,Np,Dp);
    betahatolsenbc(:,i) = betahatolsen(:,i) - (1/T)*biasbetahatolsen(:,i);
    delbc = FEp\(d-x2p*betahatolsenbc(:,i));
    deltabc = [betahatolsenbc(:,i); delbc];
    H_olsenbc = vc_olsen(d,X2,deltabc,Dp);
    s2hat_olsenbc(:,i) = diag(H_olsenbc(1:p2,1:p2));
    
    muolsenbc = X2*deltabc;
    
    meffhatolsenbc(:,i) = betahatolsenbc(:,i);
    ameffhatolsenbc(:,i) = betahatolsenbc(:,i);
    s2hat_meff_olsenbc(:,i) = s2hat_olsenbc(:,i);
    s2hat_ameff_olsenbc(:,i) = s2hat_olsenbc(:,i);
    
    meffhatolsenbc_fs(:,i) = (Np/N)*betahatolsenbc(:,i);
    ameffhatolsenbc_fs(:,i) = (Np/N)*betahatolsenbc(:,i);
    s2hat_meff_olsenbc_fs(:,i) = ((Np/N)^2)*s2hat_olsenbc(:,i);
    s2hat_ameff_olsenbc_fs(:,i) = ((Np/N)^2)*s2hat_olsenbc(:,i);

    meff2hatolsenbc_fs(i) = (Np/N)*betahatolsenbc(1,i);
    ameff2hatolsenbc_fs(i) = (Np/N)*betahatolsenbc(1,i);
    s2hat_meff2_olsenbc_fs(i) = ((Np/N)^2)*s2hat_olsenbc(1,i);
    s2hat_ameff2_olsenbc_fs(i) = ((Np/N)^2)*s2hat_olsenbc(1,i);

% MLE PROBIT;
    deltahat = glmfit1(X2,[d ones(size(d,1),1)],'binomial','probit','off',[ ],[ ] ,'off');
    Hhat_mle = avc_probit(d,X2,deltahat,Dp);
    s2hat_mle(:,i) = diag(Hhat_mle(1:p2,1:p2));
    bhat1(:,i) = deltahat(1:p2,1);    
    
    muhat = X2*deltahat;

    x2bar(:,i) = mean(x2p)';
    s2x2bar = cov(x2p,1) / size(x2p,1);
    x2bar_y0(:,i) = mean(x2p_y0)';
    s2x2bar_y0 = cov(x2p_y0,1) / size(x2p_y0,1);
    x2bar_y1(:,i) = mean(x2p_y1)';
    s2x2bar_y1 = cov(x2p_y1,1) / size(x2p_y1,1);
    
    meffhat(:,i) = bhat1(:,i) * mean(normpdf(x2bar(:,i)' * bhat1(:,i) + deltahat((p2+1):size(deltahat,1),1)));
    ameffhat(:,i) = bhat1(:,i) * mean(normpdf(X2*deltahat));
    Hhat_meff_mle = vc_meff_probit(d, x2bar(:,i), deltahat, Hhat_mle, s2x2bar, Np, p2);
    s2hat_meff_mle(:,i) = diag(Hhat_meff_mle);
    Hhat_ameff_mle = vc_ameff_probit(d, X2, deltahat, Hhat_mle, p2, Np*T);
    s2hat_ameff_mle(:,i) = diag(Hhat_ameff_mle);
    
    meffhat_fs(:,i) = bhat1(:,i) * sum(normpdf(x2bar_fs(:,i)' * bhat1(:,i) + deltahat((p2+1):size(deltahat,1),1)))/N;
    ameffhat_fs(:,i) = bhat1(:,i) * sum(normpdf(X2*deltahat))/(N*T);
    Hhat_meff_mle_fs = vc_meff_probit(d, x2bar_fs(:,i), deltahat, Hhat_mle, s2x2bar_fs, N, p2);
    s2hat_meff_mle_fs(:,i) = diag(Hhat_meff_mle_fs);
    Hhat_ameff_mle_fs = vc_ameff_probit(d, X2, deltahat, Hhat_mle, p2, N*T);
    s2hat_ameff_mle_fs(:,i) = diag(Hhat_ameff_mle_fs);

    meff2hat_fs(i) = sum(normcdf(x2bar_y1_fs(:,i)' * bhat1(:,i) + deltahat((p2+1):size(deltahat,1),1)) - ...
        normcdf(x2bar_y0_fs(:,i)' * bhat1(:,i) + deltahat((p2+1):size(deltahat,1),1)))/N;
    ameff2hat_fs(i) = sum(normcdf(X2_y1 * deltahat) - normcdf(X2_y0 * deltahat))/(N*T);
    s2hat_meff2_mle_fs(i) = vc_meff2_probit(x2bar_y0_fs(:,i),x2bar_y1_fs(:,i), deltahat, Hhat_mle, s2x2bar_fs, N, p2);
    s2hat_ameff2_mle_fs(i) = vc_ameff2_probit(X2_y0, X2_y1, deltahat, Hhat_mle, p2, N*T);

    meff3hat_fs(:,i) = bhat1(:,i) * sum(normpdf(x2bar_y0_fs(:,i)' * bhat1(:,i) + deltahat((p2+1):size(deltahat,1),1)))/N;
    ameff3hat_fs(:,i) = bhat1(:,i) * sum(normpdf(X2_y0*deltahat))/(N*T);
    Hhat_meff3_mle_fs = vc_meff_probit(d, x2bar_y0_fs(:,i), deltahat, Hhat_mle, s2x2bar_y0_fs, N, p2);
    s2hat_meff3_mle_fs(:,i) = diag(Hhat_meff3_mle_fs);
    Hhat_ameff3_mle_fs = vc_ameff_probit(d, X2_y0, deltahat, Hhat_mle, p2, N*T);
    s2hat_ameff3_mle_fs(:,i) = diag(Hhat_ameff3_mle_fs);

    meff4hat_fs(:,i) = bhat1(:,i) * sum(normpdf(x2bar_y1_fs(:,i)' * bhat1(:,i) + deltahat((p2+1):size(deltahat,1),1)))/N;
    ameff4hat_fs(:,i) = bhat1(:,i) * sum(normpdf(X2_y1*deltahat))/(N*T);
    Hhat_meff4_mle_fs = vc_meff_probit(d, x2bar_y1_fs(:,i), deltahat, Hhat_mle, s2x2bar_y1_fs, N, p2);
    s2hat_meff4_mle_fs(:,i) = diag(Hhat_meff4_mle_fs);
    Hhat_ameff4_mle_fs = vc_ameff_probit(d, X2_y1, deltahat, Hhat_mle, p2, N*T);
    s2hat_ameff4_mle_fs(:,i) = diag(Hhat_ameff4_mle_fs);

    
% ANALYTICAL BC MLE PROBIT;    
    biasbetahatbc1(:,i) = bias_beta_probit_mle(d,X2,deltahat,Np,Dp);
    bhatbc1(:,i) = bhat1(:,i) - (1/T)*biasbetahatbc1(:,i);
    b1 = bhatbc1(:,i);
    delhat1 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','probit','off',X2(:,1:p2)*b1,[ ] ,'off');
    deltahat1 = [bhatbc1(:,i);delhat1];

    Hhat_bc1 = avc_probit(d,X2,[b1;delhat1],Dp);
    s2hat_bc1(:,i) = diag(Hhat_bc1(1:p2,1:p2));


    biasalphahatbc1 = bias_alpha_probit(d,X2,[bhatbc1(:,i);delhat1],Dp);
    sigma2alphahatbc1 = sigma2_alpha_probit(d,X2,[bhatbc1(:,i);delhat1],Dp);
    phialphahatbc1 = phi_alpha_probit(d,X2,[bhatbc1(:,i);delhat1],Dp);

    muhatbc1 = x2p*bhatbc1(:,i) + kron(delhat1,ones(T,1));
    muhatbc1_y0 = x2p_y0*bhatbc1(:,i) + kron(delhat1,ones(T,1));
    muhatbc1_y1 = x2p_y1*bhatbc1(:,i) + kron(delhat1,ones(T,1));
    
    bias_meff_bc1 = bias_meff_probit(x2bar(:,i), deltahat1, biasalphahatbc1, sigma2alphahatbc1,p2,Dp,Np);  
    meffhatbc1(:,i) = bhatbc1(:,i) * mean(normpdf(x2bar(:,i)' * bhatbc1(:,i) + deltahat1((p2+1):size(deltahat1,1),1))) - bias_meff_bc1/T;
    bias_ameff_bc1 = bias_ameff_probit(muhatbc1, deltahat1, biasalphahatbc1, sigma2alphahatbc1, phialphahatbc1, p2 ,Dp,Np*T);
    ameffhatbc1(:,i) = bhatbc1(:,i) * mean(normpdf(X2*deltahat1)) - bias_ameff_bc1/T;
    Hhat_meff_bc1 = vc_meff_probit(d, x2bar(:,i), deltahat1, Hhat_bc1, s2x2bar, Np, p2);
    s2hat_meff_bc1(:,i) = diag(Hhat_meff_bc1);
    Hhat_ameff_bc1 = vc_ameff_probit(d, X2, deltahat1, Hhat_bc1, p2, Np*T);
    s2hat_ameff_bc1(:,i) = diag(Hhat_ameff_bc1);
    
    bias_meff_bc1_fs = bias_meff_probit(x2bar_fs(:,i), deltahat1, biasalphahatbc1, sigma2alphahatbc1,p2,Dp,N);  
    meffhatbc1_fs(:,i) = bhatbc1(:,i) * sum(normpdf(x2bar_fs(:,i)' * bhatbc1(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N - bias_meff_bc1_fs/T;
    bias_ameff_bc1_fs = bias_ameff_probit(muhatbc1, deltahat1, biasalphahatbc1, sigma2alphahatbc1, phialphahatbc1, p2 ,Dp, N*T);
    ameffhatbc1_fs(:,i) = bhatbc1(:,i) * sum(normpdf(X2*deltahat1))/(N*T) - bias_ameff_bc1_fs/T;
    Hhat_meff_bc1_fs = vc_meff_probit(d, x2bar_fs(:,i), deltahat1, Hhat_bc1, s2x2bar_fs, N, p2);
    s2hat_meff_bc1_fs(:,i) = diag(Hhat_meff_bc1_fs);
    Hhat_ameff_bc1_fs = vc_ameff_probit(d, X2, deltahat1, Hhat_bc1, p2, N*T);
    s2hat_ameff_bc1_fs(:,i) = diag(Hhat_ameff_bc1_fs);

    bias_meff2_bc1_fs = bias_meff2_probit(x2bar_y0_fs(:,i), x2bar_y1_fs(:,i), deltahat1, biasalphahatbc1, sigma2alphahatbc1,p2,Dp,N);  
    meff2hatbc1_fs(i) = sum(normcdf(x2bar_y1_fs(:,i)' * bhatbc1(:,i) + deltahat1((p2+1):size(deltahat1,1),1)) - ...
        normcdf(x2bar_y0_fs(:,i)' * bhatbc1(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N - bias_meff2_bc1_fs/T;
    bias_ameff2_bc1_fs = bias_ameff2_probit(muhatbc1_y0, muhatbc1_y1, deltahat1, biasalphahatbc1, sigma2alphahatbc1, phialphahatbc1, p2 ,Dp, N*T);
    ameff2hatbc1_fs(i) = sum(normcdf(muhatbc1_y1) - normcdf(muhatbc1_y0))/(N*T) - bias_ameff2_bc1_fs/T;
    s2hat_meff2_bc1_fs(i) = vc_meff2_probit(x2bar_y0_fs(:,i),x2bar_y1_fs(:,i), deltahat1, Hhat_bc1, s2x2bar_fs, N, p2);
    s2hat_ameff2_bc1_fs(i) = vc_ameff2_probit(X2_y0, X2_y1, deltahat1, Hhat_bc1, p2, N*T);

    bias_meff3_bc1_fs = bias_meff_probit(x2bar_y0_fs(:,i), deltahat1, biasalphahatbc1, sigma2alphahatbc1,p2,Dp,N);  
    meff3hatbc1_fs(:,i) = bhatbc1(:,i) * sum(normpdf(x2bar_y0_fs(:,i)' * bhatbc1(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N - bias_meff3_bc1_fs/T;
    bias_ameff3_bc1_fs = bias_ameff_probit(muhatbc1_y0, deltahat1, biasalphahatbc1, sigma2alphahatbc1, phialphahatbc1, p2 ,Dp, N*T);
    ameff3hatbc1_fs(:,i) = bhatbc1(:,i) * sum(normpdf(X2_y0*deltahat1))/(N*T) - bias_ameff3_bc1_fs/T;
    Hhat_meff3_bc1_fs = vc_meff_probit(d, x2bar_y0_fs(:,i), deltahat1, Hhat_bc1, s2x2bar_y0_fs, N, p2);
    s2hat_meff3_bc1_fs(:,i) = diag(Hhat_meff3_bc1_fs);
    Hhat_ameff3_bc1_fs = vc_ameff_probit(d, X2_y0, deltahat1, Hhat_bc1, p2, N*T);
    s2hat_ameff3_bc1_fs(:,i) = diag(Hhat_ameff3_bc1_fs);

    
    bias_meff4_bc1_fs = bias_meff_probit(x2bar_y1_fs(:,i), deltahat1, biasalphahatbc1, sigma2alphahatbc1,p2,Dp,N);  
    meff4hatbc1_fs(:,i) = bhatbc1(:,i) * sum(normpdf(x2bar_y1_fs(:,i)' * bhatbc1(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N - bias_meff4_bc1_fs/T;
    bias_ameff4_bc1_fs = bias_ameff_probit(muhatbc1_y1, deltahat1, biasalphahatbc1, sigma2alphahatbc1, phialphahatbc1, p2 ,Dp, N*T);
    ameff4hatbc1_fs(:,i) = bhatbc1(:,i) * sum(normpdf(X2_y1*deltahat1))/(N*T) - bias_ameff4_bc1_fs/T;
    Hhat_meff4_bc1_fs = vc_meff_probit(d, x2bar_y1_fs(:,i), deltahat1, Hhat_bc1, s2x2bar_y1_fs, N, p2);
    s2hat_meff4_bc1_fs(:,i) = diag(Hhat_meff4_bc1_fs);
    Hhat_ameff4_bc1_fs = vc_ameff_probit(d, X2_y1, deltahat1, Hhat_bc1, p2, N*T);
    s2hat_ameff4_bc1_fs(:,i) = diag(Hhat_ameff4_bc1_fs);

    
    meffhat1_fs(:,i) = bhatbc1(:,i) * sum(normpdf(x2bar_y0(:,i)' * bhatbc1(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N ;
    ameffhat1_fs(:,i) = bhatbc1(:,i) * sum(normpdf(X2*deltahat1))/(N*T);
    meff2hat1_fs(i) = sum(normcdf(x2bar_y1_fs(:,i)' * bhatbc1(:,i) + deltahat1((p2+1):size(deltahat1,1),1)) - ...
        normcdf(x2bar_y0_fs(:,i)' * bhatbc1(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N;
    ameff2hat1_fs(i) = sum(normcdf(muhatbc1_y1) - normcdf(muhatbc1_y0))/(N*T);
    
    
% ANALYTICAL-M BC MLE PROBIT;    
    biasbetahatbc2(:,i) = bias_beta_probit(d,X2,deltahat,Np,Dp);
%    BIAS2_2(:,i) = bias_beta(d,X2,delta,Np,Dp);
    bhatbc2(:,i) = bhat1(:,i) - (1/T)*biasbetahatbc2(:,i);
    b2 = bhatbc2(:,i);
    delhat2 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','probit','off',X2(:,1:p2)*b2,[ ] ,'off');
    deltahat2 = [bhatbc2(:,i);delhat2];

    Hhat_bc2 = avc_probit(d,X2,[b2;delhat2],Dp);
    s2hat_bc2(:,i) = diag(Hhat_bc2(1:p2,1:p2));

    biasalphahatbc2 = bias_alpha_probit(d,X2,[bhatbc2(:,i);delhat2],Dp);
    sigma2alphahatbc2 = sigma2_alpha_probit(d,X2,[bhatbc2(:,i);delhat2],Dp);
    phialphahatbc2 = phi_alpha_probit(d,X2,[bhatbc2(:,i);delhat2],Dp);

    muhatbc2 = x2p*bhatbc2(:,i) + kron(delhat2,ones(T,1));
    muhatbc2_y0 = x2p_y0*bhatbc2(:,i) + kron(delhat2,ones(T,1));
    muhatbc2_y1 = x2p_y1*bhatbc2(:,i) + kron(delhat2,ones(T,1));

    bias_meff_bc2 = bias_meff_probit(x2bar(:,i), deltahat2, biasalphahatbc2, sigma2alphahatbc2,p2,Dp,Np);  
    meffhatbc2(:,i) = bhatbc2(:,i) * mean(normpdf(x2bar(:,i)' * bhatbc2(:,i) + deltahat2((p2+1):size(deltahat2,1),1))) - bias_meff_bc2/T;
    bias_ameff_bc2 = bias_ameff_probit(muhatbc2, deltahat2, biasalphahatbc2, sigma2alphahatbc2, phialphahatbc2, p2 ,Dp, Np*T);
    ameffhatbc2(:,i) = bhatbc2(:,i) * mean(normpdf(X2*deltahat2)) - bias_ameff_bc2/T;
    Hhat_meff_bc2 = vc_meff_probit(d, x2bar(:,i), deltahat2, Hhat_bc2, s2x2bar, Np, p2);
    s2hat_meff_bc2(:,i) = diag(Hhat_meff_bc2);
    Hhat_ameff_bc2 = vc_ameff_probit(d, X2, deltahat2, Hhat_bc2, p2, Np*T);
    s2hat_ameff_bc2(:,i) = diag(Hhat_ameff_bc2);
    
    bias_meff_bc2_fs = bias_meff_probit(x2bar_fs(:,i), deltahat2, biasalphahatbc2, sigma2alphahatbc2,p2,Dp,N);  
    meffhatbc2_fs(:,i) = bhatbc2(:,i) * sum(normpdf(x2bar(:,i)' * bhatbc2(:,i) + deltahat2((p2+1):size(deltahat2,1),1)))/N - bias_meff_bc2_fs/T;
    bias_ameff_bc2_fs = bias_ameff_probit(muhatbc2, deltahat2, biasalphahatbc2, sigma2alphahatbc2, phialphahatbc2, p2 ,Dp, N*T);
    ameffhatbc2_fs(:,i) = bhatbc2(:,i) * sum(normpdf(X2*deltahat2))/(N*T) - bias_ameff_bc2_fs/T;
    Hhat_meff_bc2_fs = vc_meff_probit(d, x2bar_fs(:,i), deltahat2, Hhat_bc2, s2x2bar_fs, N, p2);
    s2hat_meff_bc2_fs(:,i) = diag(Hhat_meff_bc2_fs);
    Hhat_ameff_bc2_fs = vc_ameff_probit(d, X2, deltahat2, Hhat_bc2, p2, N*T);
    s2hat_ameff_bc2_fs(:,i) = diag(Hhat_ameff_bc2_fs);

    bias_meff2_bc2_fs = bias_meff2_probit(x2bar_y0_fs(:,i), x2bar_y1_fs(:,i), deltahat2, biasalphahatbc2, sigma2alphahatbc2,p2,Dp,N);  
    meff2hatbc2_fs(i) = sum(normcdf(x2bar_y1_fs(:,i)' * bhatbc2(:,i) + deltahat2((p2+1):size(deltahat2,1),1)) - ...
        normcdf(x2bar_y0_fs(:,i)' * bhatbc2(:,i) + deltahat2((p2+1):size(deltahat2,1),1)))/N - bias_meff2_bc2_fs/T;
    bias_ameff2_bc2_fs = bias_ameff2_probit(muhatbc2_y0, muhatbc2_y1, deltahat2, biasalphahatbc2, sigma2alphahatbc2, phialphahatbc2, p2 ,Dp, N*T);
    ameff2hatbc2_fs(i) = sum(normcdf(muhatbc2_y1) - normcdf(muhatbc2_y0))/(N*T) - bias_ameff2_bc2_fs/T;
    s2hat_meff2_bc2_fs(i) = vc_meff2_probit(x2bar_y0_fs(:,i),x2bar_y1_fs(:,i), deltahat2, Hhat_bc2, s2x2bar_fs, N, p2);
    s2hat_ameff2_bc2_fs(i) = vc_ameff2_probit(X2_y0, X2_y1, deltahat2, Hhat_bc2, p2, N*T);

    bias_meff3_bc2_fs = bias_meff_probit(x2bar_y0_fs(:,i), deltahat1, biasalphahatbc2, sigma2alphahatbc2,p2,Dp,N);  
    meff3hatbc2_fs(:,i) = bhatbc2(:,i) * sum(normpdf(x2bar_y0_fs(:,i)' * bhatbc2(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N - bias_meff3_bc2_fs/T;
    bias_ameff3_bc2_fs = bias_ameff_probit(muhatbc2_y0, deltahat1, biasalphahatbc2, sigma2alphahatbc2, phialphahatbc2, p2 ,Dp, N*T);
    ameff3hatbc2_fs(:,i) = bhatbc2(:,i) * sum(normpdf(X2_y0*deltahat1))/(N*T) - bias_ameff3_bc2_fs/T;
    Hhat_meff3_bc2_fs = vc_meff_probit(d, x2bar_y0_fs(:,i), deltahat1, Hhat_bc2, s2x2bar_y0_fs, N, p2);
    s2hat_meff3_bc2_fs(:,i) = diag(Hhat_meff3_bc2_fs);
    Hhat_ameff3_bc2_fs = vc_ameff_probit(d, X2_y0, deltahat1, Hhat_bc2, p2, N*T);
    s2hat_ameff3_bc2_fs(:,i) = diag(Hhat_ameff3_bc2_fs);

    
    bias_meff4_bc2_fs = bias_meff_probit(x2bar_y1_fs(:,i), deltahat1, biasalphahatbc2, sigma2alphahatbc2,p2,Dp,N);  
    meff4hatbc2_fs(:,i) = bhatbc2(:,i) * sum(normpdf(x2bar_y1_fs(:,i)' * bhatbc2(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N - bias_meff4_bc2_fs/T;
    bias_ameff4_bc2_fs = bias_ameff_probit(muhatbc2_y1, deltahat1, biasalphahatbc2, sigma2alphahatbc2, phialphahatbc2, p2 ,Dp, N*T);
    ameff4hatbc2_fs(:,i) = bhatbc2(:,i) * sum(normpdf(X2_y1*deltahat1))/(N*T) - bias_ameff4_bc2_fs/T;
    Hhat_meff4_bc2_fs = vc_meff_probit(d, x2bar_y1_fs(:,i), deltahat1, Hhat_bc2, s2x2bar_y1_fs, N, p2);
    s2hat_meff4_bc2_fs(:,i) = diag(Hhat_meff4_bc2_fs);
    Hhat_ameff4_bc2_fs = vc_ameff_probit(d, X2_y1, deltahat1, Hhat_bc2, p2, N*T);
    s2hat_ameff4_bc2_fs(:,i) = diag(Hhat_ameff4_bc2_fs);

    meffhat2_fs(:,i) = bhatbc2(:,i) * sum(normpdf(x2bar_y0(:,i)' * bhatbc2(:,i) + deltahat2((p2+1):size(deltahat2,1),1)))/N ;
    ameffhat2_fs(:,i) = bhatbc2(:,i) * sum(normpdf(X2*deltahat2))/(N*T);
    meff2hat2_fs(i) = sum(normcdf(x2bar_y1_fs(:,i)' * bhatbc2(:,i) + deltahat2((p2+1):size(deltahat2,1),1)) - ...
        normcdf(x2bar_y0_fs(:,i)' * bhatbc2(:,i) + deltahat2((p2+1):size(deltahat2,1),1)))/N;
    ameff2hat2_fs(i) = sum(normcdf(muhatbc2_y1) - normcdf(muhatbc2_y0))/(N*T);

% ANALYTICAL 2 BC MLE PROBIT;    
    biasbetahatbc3(:,i) = bias_beta_probit_mle2(d,X2,deltahat,Np,Dp);
    bhatbc3(:,i) = bhat1(:,i) - (1/T)*biasbetahatbc3(:,i);
    b3 = bhatbc3(:,i);
    delhat3 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','probit','off',X2(:,1:p2)*b3,[ ] ,'off');
    deltahat3 = [bhatbc3(:,i);delhat3];

    Hhat_bc3 = avc_probit(d,X2,[b3;delhat3],Dp);
    s2hat_bc3(:,i) = diag(Hhat_bc3(1:p2,1:p2));

    biasalphahatbc3 = bias_alpha_probit_mle2(d,X2,[bhatbc3(:,i);delhat3],Dp);
    sigma2alphahatbc3 = sigma2_alpha_probit_mle2(d,X2,[bhatbc3(:,i);delhat3],Dp);
    phialphahatbc3 = phi_alpha_probit_mle2(d,X2,[bhatbc3(:,i);delhat3],Dp);

    muhatbc3 = x2p*bhatbc3(:,i) + kron(delhat3,ones(T,1));
    muhatbc3_y0 = x2p_y0*bhatbc3(:,i) + kron(delhat3,ones(T,1));
    muhatbc3_y1 = x2p_y1*bhatbc3(:,i) + kron(delhat3,ones(T,1));

    bias_meff_bc3 = bias_meff_probit(x2bar(:,i), deltahat3, biasalphahatbc3, sigma2alphahatbc3,p2,Dp,Np);  
    meffhatbc3(:,i) = bhatbc3(:,i) * mean(normpdf(x2bar(:,i)' * bhatbc3(:,i) + deltahat3((p2+1):size(deltahat3,1),1))) - bias_meff_bc3/T;
    bias_ameff_bc3 = bias_ameff_probit(muhatbc3, deltahat3, biasalphahatbc3, sigma2alphahatbc3, phialphahatbc3, p2 ,Dp, Np*T);
    ameffhatbc3(:,i) = bhatbc3(:,i) * mean(normpdf(X2*deltahat3)) - bias_ameff_bc3/T;
    Hhat_meff_bc3 = vc_meff_probit(d, x2bar(:,i), deltahat3, Hhat_bc3, s2x2bar, Np, p2);
    s2hat_meff_bc3(:,i) = diag(Hhat_meff_bc3);
    Hhat_ameff_bc3 = vc_ameff_probit(d, X2, deltahat3, Hhat_bc3, p2, Np*T);
    s2hat_ameff_bc3(:,i) = diag(Hhat_ameff_bc3);
    
    bias_meff_bc3_fs = bias_meff_probit(x2bar_fs(:,i), deltahat3, biasalphahatbc3, sigma2alphahatbc3,p2,Dp,N);  
    meffhatbc3_fs(:,i) = bhatbc3(:,i) * sum(normpdf(x2bar(:,i)' * bhatbc3(:,i) + deltahat3((p2+1):size(deltahat3,1),1)))/N - bias_meff_bc3_fs/T;
    bias_ameff_bc3_fs = bias_ameff_probit(muhatbc3, deltahat3, biasalphahatbc3, sigma2alphahatbc3, phialphahatbc3, p2 ,Dp, N*T);
    ameffhatbc3_fs(:,i) = bhatbc3(:,i) * sum(normpdf(X2*deltahat3))/(N*T) - bias_ameff_bc3_fs/T;
    Hhat_meff_bc3_fs = vc_meff_probit(d, x2bar_fs(:,i), deltahat3, Hhat_bc3, s2x2bar_fs, N, p2);
    s2hat_meff_bc3_fs(:,i) = diag(Hhat_meff_bc3_fs);
    Hhat_ameff_bc3_fs = vc_ameff_probit(d, X2, deltahat3, Hhat_bc3, p2, N*T);
    s2hat_ameff_bc3_fs(:,i) = diag(Hhat_ameff_bc3_fs);

    bias_meff2_bc3_fs = bias_meff2_probit(x2bar_y0_fs(:,i), x2bar_y1_fs(:,i), deltahat3, biasalphahatbc3, sigma2alphahatbc3,p2,Dp,N);  
    meff2hatbc3_fs(i) = sum(normcdf(x2bar_y1_fs(:,i)' * bhatbc3(:,i) + deltahat3((p2+1):size(deltahat3,1),1)) - ...
        normcdf(x2bar_y0_fs(:,i)' * bhatbc3(:,i) + deltahat3((p2+1):size(deltahat3,1),1)))/N - bias_meff2_bc3_fs/T;
    bias_ameff2_bc3_fs = bias_ameff2_probit(muhatbc3_y0, muhatbc3_y1, deltahat3, biasalphahatbc3, sigma2alphahatbc3, phialphahatbc3, p2 ,Dp, N*T);
    ameff2hatbc3_fs(i) = sum(normcdf(muhatbc3_y1) - normcdf(muhatbc3_y0))/(N*T) - bias_ameff2_bc3_fs/T;
    s2hat_meff2_bc3_fs(i) = vc_meff2_probit(x2bar_y0_fs(:,i),x2bar_y1_fs(:,i), deltahat3, Hhat_bc3, s2x2bar_fs, N, p2);
    s2hat_ameff2_bc3_fs(i) = vc_ameff2_probit(X2_y0, X2_y1, deltahat3, Hhat_bc3, p2, N*T);

    bias_meff3_bc3_fs = bias_meff_probit(x2bar_y0_fs(:,i), deltahat1, biasalphahatbc3, sigma2alphahatbc3,p2,Dp,N);  
    meff3hatbc3_fs(:,i) = bhatbc3(:,i) * sum(normpdf(x2bar_y0_fs(:,i)' * bhatbc3(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N - bias_meff3_bc3_fs/T;
    bias_ameff3_bc3_fs = bias_ameff_probit(muhatbc3_y0, deltahat1, biasalphahatbc3, sigma2alphahatbc3, phialphahatbc3, p2 ,Dp, N*T);
    ameff3hatbc3_fs(:,i) = bhatbc3(:,i) * sum(normpdf(X2_y0*deltahat1))/(N*T) - bias_ameff3_bc3_fs/T;
    Hhat_meff3_bc3_fs = vc_meff_probit(d, x2bar_y0_fs(:,i), deltahat1, Hhat_bc3, s2x2bar_y0_fs, N, p2);
    s2hat_meff3_bc3_fs(:,i) = diag(Hhat_meff3_bc3_fs);
    Hhat_ameff3_bc3_fs = vc_ameff_probit(d, X2_y0, deltahat1, Hhat_bc3, p2, N*T);
    s2hat_ameff3_bc3_fs(:,i) = diag(Hhat_ameff3_bc3_fs);

    
    bias_meff4_bc3_fs = bias_meff_probit(x2bar_y1_fs(:,i), deltahat1, biasalphahatbc3, sigma2alphahatbc3,p2,Dp,N);  
    meff4hatbc3_fs(:,i) = bhatbc3(:,i) * sum(normpdf(x2bar_y1_fs(:,i)' * bhatbc3(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N - bias_meff4_bc3_fs/T;
    bias_ameff4_bc3_fs = bias_ameff_probit(muhatbc3_y1, deltahat1, biasalphahatbc3, sigma2alphahatbc3, phialphahatbc3, p2 ,Dp, N*T);
    ameff4hatbc3_fs(:,i) = bhatbc3(:,i) * sum(normpdf(X2_y1*deltahat1))/(N*T) - bias_ameff4_bc3_fs/T;
    Hhat_meff4_bc3_fs = vc_meff_probit(d, x2bar_y1_fs(:,i), deltahat1, Hhat_bc3, s2x2bar_y1_fs, N, p2);
    s2hat_meff4_bc3_fs(:,i) = diag(Hhat_meff4_bc3_fs);
    Hhat_ameff4_bc3_fs = vc_ameff_probit(d, X2_y1, deltahat1, Hhat_bc3, p2, N*T);
    s2hat_ameff4_bc3_fs(:,i) = diag(Hhat_ameff4_bc3_fs);

    meffhat3_fs(:,i) = bhatbc3(:,i) * sum(normpdf(x2bar_y0(:,i)' * bhatbc3(:,i) + deltahat3((p2+1):size(deltahat3,1),1)))/N ;
    ameffhat3_fs(:,i) = bhatbc3(:,i) * sum(normpdf(X2*deltahat3))/(N*T);
    meff2hat3_fs(i) = sum(normcdf(x2bar_y1_fs(:,i)' * bhatbc3(:,i) + deltahat3((p2+1):size(deltahat3,1),1)) - ...
        normcdf(x2bar_y0_fs(:,i)' * bhatbc3(:,i) + deltahat3((p2+1):size(deltahat3,1),1)))/N;
    ameff2hat3_fs(i) = sum(normcdf(muhatbc3_y1) - normcdf(muhatbc3_y0))/(N*T);

% ANALYTICAL 3 BC MLE PROBIT;    
    biasbetahatbc4(:,i) = bias_beta_probit_mle3(d,X2,deltahat,Np,Dp);
    bhatbc4(:,i) = bhat1(:,i) - (1/T)*biasbetahatbc4(:,i);
    b4 = bhatbc4(:,i);
    delhat4 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','probit','off',X2(:,1:p2)*b4,[ ] ,'off');
    deltahat4 = [bhatbc4(:,i);delhat4];

    Hhat_bc4 = avc_probit(d,X2,[b4;delhat4],Dp);
    s2hat_bc4(:,i) = diag(Hhat_bc4(1:p2,1:p2));

    biasalphahatbc4 = bias_alpha_probit_mle2(d,X2,[bhatbc4(:,i);delhat4],Dp);
    sigma2alphahatbc4 = sigma2_alpha_probit_mle2(d,X2,[bhatbc4(:,i);delhat4],Dp);
    phialphahatbc4 = phi_alpha_probit_mle2(d,X2,[bhatbc4(:,i);delhat4],Dp);

    muhatbc4 = x2p*bhatbc4(:,i) + kron(delhat4,ones(T,1));
    muhatbc4_y0 = x2p_y0*bhatbc4(:,i) + kron(delhat4,ones(T,1));
    muhatbc4_y1 = x2p_y1*bhatbc4(:,i) + kron(delhat4,ones(T,1));

    bias_meff_bc4 = bias_meff_probit(x2bar(:,i), deltahat4, biasalphahatbc4, sigma2alphahatbc4,p2,Dp, Np);  
    meffhatbc4(:,i) = bhatbc4(:,i) * mean(normpdf(x2bar(:,i)' * bhatbc4(:,i) + deltahat4((p2+1):size(deltahat4,1),1))) - bias_meff_bc4/T;
    bias_ameff_bc4 = bias_ameff_probit(muhatbc4, deltahat4, biasalphahatbc4, sigma2alphahatbc4, phialphahatbc4, p2 ,Dp, Np*T);
    ameffhatbc4(:,i) = bhatbc4(:,i) * mean(normpdf(X2*deltahat4)) - bias_ameff_bc4/T;
    Hhat_meff_bc4 = vc_meff_probit(d, x2bar(:,i), deltahat4, Hhat_bc4, s2x2bar, Np, p2);
    s2hat_meff_bc4(:,i) = diag(Hhat_meff_bc4);
    Hhat_ameff_bc4 = vc_ameff_probit(d, X2, deltahat4, Hhat_bc4, p2, Np*T);
    s2hat_ameff_bc4(:,i) = diag(Hhat_ameff_bc4);

        
    bias_meff_bc4_fs = bias_meff_probit(x2bar_fs(:,i), deltahat4, biasalphahatbc4, sigma2alphahatbc4,p2,Dp,N);  
    meffhatbc4_fs(:,i) = bhatbc4(:,i) * sum(normpdf(x2bar(:,i)' * bhatbc4(:,i) + deltahat4((p2+1):size(deltahat4,1),1)))/N - bias_meff_bc4_fs/T;
    bias_ameff_bc4_fs = bias_ameff_probit(muhatbc4, deltahat4, biasalphahatbc4, sigma2alphahatbc4, phialphahatbc4, p2 ,Dp, N*T);
    ameffhatbc4_fs(:,i) = bhatbc4(:,i) * sum(normpdf(X2*deltahat4))/(N*T) - bias_ameff_bc4_fs/T;
    Hhat_meff_bc4_fs = vc_meff_probit(d, x2bar_fs(:,i), deltahat4, Hhat_bc4, s2x2bar_fs, N, p2);
    s2hat_meff_bc4_fs(:,i) = diag(Hhat_meff_bc4_fs);
    Hhat_ameff_bc4_fs = vc_ameff_probit(d, X2, deltahat4, Hhat_bc4, p2, N*T);
    s2hat_ameff_bc4_fs(:,i) = diag(Hhat_ameff_bc4_fs);

    bias_meff2_bc4_fs = bias_meff2_probit(x2bar_y0_fs(:,i), x2bar_y1_fs(:,i), deltahat4, biasalphahatbc4, sigma2alphahatbc4,p2,Dp,N);  
    meff2hatbc4_fs(i) = sum(normcdf(x2bar_y1_fs(:,i)' * bhatbc4(:,i) + deltahat4((p2+1):size(deltahat4,1),1)) - ...
        normcdf(x2bar_y0_fs(:,i)' * bhatbc4(:,i) + deltahat4((p2+1):size(deltahat4,1),1)))/N - bias_meff2_bc4_fs/T;
    bias_ameff2_bc4_fs = bias_ameff2_probit(muhatbc4_y0, muhatbc4_y1, deltahat4, biasalphahatbc4, sigma2alphahatbc4, phialphahatbc4, p2 ,Dp, N*T);
    ameff2hatbc4_fs(i) = sum(normcdf(muhatbc4_y1) - normcdf(muhatbc4_y0))/(N*T) - bias_ameff2_bc4_fs/T;
    s2hat_meff2_bc4_fs(i) = vc_meff2_probit(x2bar_y0_fs(:,i),x2bar_y1_fs(:,i), deltahat4, Hhat_bc4, s2x2bar_fs, N, p2);
    s2hat_ameff2_bc4_fs(i) = vc_ameff2_probit(X2_y0, X2_y1, deltahat4, Hhat_bc4, p2, N*T);

    bias_meff3_bc4_fs = bias_meff_probit(x2bar_y0_fs(:,i), deltahat1, biasalphahatbc4, sigma2alphahatbc4,p2,Dp,N);  
    meff3hatbc4_fs(:,i) = bhatbc4(:,i) * sum(normpdf(x2bar_y0_fs(:,i)' * bhatbc4(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N - bias_meff3_bc4_fs/T;
    bias_ameff3_bc4_fs = bias_ameff_probit(muhatbc4_y0, deltahat1, biasalphahatbc4, sigma2alphahatbc4, phialphahatbc4, p2 ,Dp, N*T);
    ameff3hatbc4_fs(:,i) = bhatbc4(:,i) * sum(normpdf(X2_y0*deltahat1))/(N*T) - bias_ameff3_bc4_fs/T;
    Hhat_meff3_bc4_fs = vc_meff_probit(d, x2bar_y0_fs(:,i), deltahat1, Hhat_bc4, s2x2bar_y0_fs, N, p2);
    s2hat_meff3_bc4_fs(:,i) = diag(Hhat_meff3_bc4_fs);
    Hhat_ameff3_bc4_fs = vc_ameff_probit(d, X2_y0, deltahat1, Hhat_bc4, p2, N*T);
    s2hat_ameff3_bc4_fs(:,i) = diag(Hhat_ameff3_bc4_fs);

    
    bias_meff4_bc4_fs = bias_meff_probit(x2bar_y1_fs(:,i), deltahat1, biasalphahatbc4, sigma2alphahatbc4,p2,Dp,N);  
    meff4hatbc4_fs(:,i) = bhatbc4(:,i) * sum(normpdf(x2bar_y1_fs(:,i)' * bhatbc4(:,i) + deltahat1((p2+1):size(deltahat1,1),1)))/N - bias_meff4_bc4_fs/T;
    bias_ameff4_bc4_fs = bias_ameff_probit(muhatbc4_y1, deltahat1, biasalphahatbc4, sigma2alphahatbc4, phialphahatbc4, p2 ,Dp, N*T);
    ameff4hatbc4_fs(:,i) = bhatbc4(:,i) * sum(normpdf(X2_y1*deltahat1))/(N*T) - bias_ameff4_bc4_fs/T;
    Hhat_meff4_bc4_fs = vc_meff_probit(d, x2bar_y1_fs(:,i), deltahat1, Hhat_bc4, s2x2bar_y1_fs, N, p2);
    s2hat_meff4_bc4_fs(:,i) = diag(Hhat_meff4_bc4_fs);
    Hhat_ameff4_bc4_fs = vc_ameff_probit(d, X2_y1, deltahat1, Hhat_bc4, p2, N*T);
    s2hat_ameff4_bc4_fs(:,i) = diag(Hhat_ameff4_bc4_fs);

    meffhat4_fs(:,i) = bhatbc4(:,i) * sum(normpdf(x2bar_y0(:,i)' * bhatbc4(:,i) + deltahat4((p2+1):size(deltahat4,1),1)))/N ;
    ameffhat4_fs(:,i) = bhatbc4(:,i) * sum(normpdf(X2*deltahat4))/(N*T);
    meff2hat4_fs(i) = sum(normcdf(x2bar_y1_fs(:,i)' * bhatbc4(:,i) + deltahat4((p2+1):size(deltahat4,1),1)) - ...
        normcdf(x2bar_y0_fs(:,i)' * bhatbc4(:,i) + deltahat4((p2+1):size(deltahat4,1),1)))/N;
    ameff2hat4_fs(i) = sum(normcdf(muhatbc4_y1) - normcdf(muhatbc4_y0))/(N*T);

% MLE LOGIT;
    deltatilde = glmfit1(X2,[d ones(size(d,1),1)],'binomial','logit','off',[ ],[ ] ,'off');
    Htilde_mle = avc_logit(d,X2,deltatilde,Dp);
    s2tilde_mle(:,i) = diag(Htilde_mle(1:p2,1:p2));
    btilde1(:,i) = deltatilde(1:p2,1);    
    

    mutilde = X2*deltatilde;

    x2bar(:,i) = mean(x2p)';
    s2x2bar = cov(x2p,1) / size(x2p,1);
    
    mefftilde(:,i) = btilde1(:,i) * mean(logpdf(x2bar(:,i)' * btilde1(:,i) + deltatilde((p2+1):size(deltatilde,1),1)));
    amefftilde(:,i) = btilde1(:,i) * mean(logpdf(X2*deltatilde));
    Htilde_meff_mle = vc_meff_logit(d, x2bar(:,i), deltatilde, Htilde_mle, s2x2bar, Np, p2);
    s2tilde_meff_mle(:,i) = diag(Htilde_meff_mle);
    Htilde_ameff_mle = vc_ameff_logit(d, X2, deltatilde, Htilde_mle, p2, Np*T);
    s2tilde_ameff_mle(:,i) = diag(Htilde_ameff_mle);

    mefftilde_fs(:,i) = btilde1(:,i) * sum(logpdf(x2bar_fs(:,i)' * btilde1(:,i) + deltatilde((p2+1):size(deltatilde,1),1)))/N;
    amefftilde_fs(:,i) = btilde1(:,i) * sum(logpdf(X2*deltatilde))/(N*T);
    Htilde_meff_mle_fs = vc_meff_logit(d, x2bar_fs(:,i), deltatilde, Htilde_mle, s2x2bar_fs, N, p2);
    s2tilde_meff_mle_fs(:,i) = diag(Htilde_meff_mle_fs);
    Htilde_ameff_mle_fs = vc_ameff_logit(d, X2, deltatilde, Htilde_mle, p2, N*T);
    s2tilde_ameff_mle_fs(:,i) = diag(Htilde_ameff_mle_fs);

    meff2tilde_fs(i) = sum(logcdf(x2bar_y1_fs(:,i)' * btilde1(:,i) + deltatilde((p2+1):size(deltatilde,1),1)) - ...
        logcdf(x2bar_y0_fs(:,i)' * btilde1(:,i) + deltatilde((p2+1):size(deltatilde,1),1)))/N;
    ameff2tilde_fs(i) = sum(logcdf(X2_y1 * deltatilde) - logcdf(X2_y0 * deltatilde))/(N*T);
    s2tilde_meff2_mle_fs(i) = vc_meff2_logit(x2bar_y0_fs(:,i),x2bar_y1_fs(:,i), deltatilde, Htilde_mle, s2x2bar_fs, N, p2);
    s2tilde_ameff2_mle_fs(i) = vc_ameff2_logit(X2_y0, X2_y1, deltatilde, Htilde_mle, p2, N*T);

    meff3tilde_fs(:,i) = btilde1(:,i) * sum(logpdf(x2bar_y0_fs(:,i)' * btilde1(:,i) + deltatilde((p2+1):size(deltatilde,1),1)))/N;
    ameff3tilde_fs(:,i) = btilde1(:,i) * sum(logpdf(X2_y0*deltatilde))/(N*T);
    Htilde_meff3_mle_fs = vc_meff_logit(d, x2bar_y0_fs(:,i), deltatilde, Htilde_mle, s2x2bar_y0_fs, N, p2);
    s2tilde_meff3_mle_fs(:,i) = diag(Htilde_meff3_mle_fs);
    Htilde_ameff3_mle_fs = vc_ameff_logit(d, X2_y0, deltatilde, Htilde_mle, p2, N*T);
    s2tilde_ameff3_mle_fs(:,i) = diag(Htilde_ameff3_mle_fs);

    meff4tilde_fs(:,i) = btilde1(:,i) * sum(logpdf(x2bar_y1_fs(:,i)' * btilde1(:,i) + deltatilde((p2+1):size(deltatilde,1),1)))/N;
    ameff4tilde_fs(:,i) = btilde1(:,i) * sum(logpdf(X2_y1*deltatilde))/(N*T);
    Htilde_meff4_mle_fs = vc_meff_logit(d, x2bar_y1_fs(:,i), deltatilde, Htilde_mle, s2x2bar_y1_fs, N, p2);
    s2tilde_meff4_mle_fs(:,i) = diag(Htilde_meff4_mle_fs);
    Htilde_ameff4_mle_fs = vc_ameff_logit(d, X2_y1, deltatilde, Htilde_mle, p2, N*T);
    s2tilde_ameff4_mle_fs(:,i) = diag(Htilde_ameff4_mle_fs);
    
% ANALYTICAL BC MLE LOGIT;    
    biasbetatildebc1(:,i) = bias_beta_logit_mle(d,X2,deltatilde,Np,Dp);
    btildebc1(:,i) = btilde1(:,i) - (1/T)*biasbetatildebc1(:,i);
    b1 = btildebc1(:,i);
    deltilde1 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','logit','off',X2(:,1:p2)*b1,[ ] ,'off');
    deltatilde1 = [btildebc1(:,i);deltilde1];

    Htilde_bc1 = avc_logit(d,X2,[b1;deltilde1],Dp);
    s2tilde_bc1(:,i) = diag(Htilde_bc1(1:p2,1:p2));

    biasalphatildebc1 = bias_alpha_logit(d,X2,[btildebc1(:,i);deltilde1],Dp);
    sigma2alphatildebc1 = sigma2_alpha_logit(d,X2,[btildebc1(:,i);deltilde1],Dp);
    phialphatildebc1 = phi_alpha_logit(d,X2,[btildebc1(:,i);deltilde1],Dp);

    mutildebc1 = x2p*btildebc1(:,i) + kron(deltilde1,ones(T,1));
    mutildebc1_y0 = x2p_y0*btildebc1(:,i) + kron(deltilde1,ones(T,1));
    mutildebc1_y1 = x2p_y1*btildebc1(:,i) + kron(deltilde1,ones(T,1));

    bias_meff_bc1 = bias_meff_logit(x2bar(:,i), deltatilde1, biasalphatildebc1, sigma2alphatildebc1,p2,Dp, Np);  
    mefftildebc1(:,i) = btildebc1(:,i) * mean(logpdf(x2bar(:,i)' * btildebc1(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1))) - bias_meff_bc1/T;
    bias_ameff_bc1 = bias_ameff_logit(mutildebc1, deltatilde1, biasalphatildebc1, sigma2alphatildebc1, phialphatildebc1, p2 ,Dp, Np*T);
    amefftildebc1(:,i) = btildebc1(:,i) * mean(logpdf(X2*deltatilde1)) - bias_ameff_bc1/T;
    Htilde_meff_bc1 = vc_meff_logit(d, x2bar(:,i), deltatilde1, Htilde_bc1, s2x2bar, Np, p2);
    s2tilde_meff_bc1(:,i) = diag(Htilde_meff_bc1);
    Htilde_ameff_bc1 = vc_ameff_logit(d, X2, deltatilde1, Htilde_bc1, p2, Np*T);
    s2tilde_ameff_bc1(:,i) = diag(Htilde_ameff_bc1);

    bias_meff_bc1_fs = bias_meff_logit(x2bar_fs(:,i), deltatilde1, biasalphatildebc1, sigma2alphatildebc1,p2,Dp,N);  
    mefftildebc1_fs(:,i) = btildebc1(:,i) * sum(logpdf(x2bar(:,i)' * btildebc1(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)))/N - bias_meff_bc1_fs/T;
    bias_ameff_bc1_fs = bias_ameff_logit(mutildebc1, deltatilde1, biasalphatildebc1, sigma2alphatildebc1, phialphatildebc1, p2 ,Dp, N*T);
    amefftildebc1_fs(:,i) = btildebc1(:,i) * sum(logpdf(X2*deltatilde1))/(N*T) - bias_ameff_bc1_fs/T;
    Htilde_meff_bc1_fs = vc_meff_logit(d, x2bar_fs(:,i), deltatilde1, Htilde_bc1, s2x2bar_fs, N, p2);
    s2tilde_meff_bc1_fs(:,i) = diag(Htilde_meff_bc1_fs);
    Htilde_ameff_bc1_fs = vc_ameff_logit(d, X2, deltatilde1, Htilde_bc1, p2, N*T);
    s2tilde_ameff_bc1_fs(:,i) = diag(Htilde_ameff_bc1_fs);
    
    bias_meff2_bc1_fs = bias_meff2_logit(x2bar_y0_fs(:,i), x2bar_y1_fs(:,i), deltatilde1, biasalphatildebc1, sigma2alphatildebc1,p2,Dp,N);  
    meff2tildebc1_fs(i) = sum(logcdf(x2bar_y1_fs(:,i)' * btildebc1(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)) - ...
        logcdf(x2bar_y0_fs(:,i)' * btildebc1(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)))/N - bias_meff2_bc1_fs/T;
    bias_ameff2_bc1_fs = bias_ameff2_logit(mutildebc1_y0, mutildebc1_y1, deltatilde1, biasalphatildebc1, sigma2alphatildebc1, phialphatildebc1, p2 ,Dp, N*T);
    ameff2tildebc1_fs(i) = sum(logcdf(mutildebc1_y1) - logcdf(mutildebc1_y0))/(N*T) - bias_ameff2_bc1_fs/T;
    s2tilde_meff2_bc1_fs(i) = vc_meff2_logit(x2bar_y0_fs(:,i),x2bar_y1_fs(:,i), deltatilde1, Htilde_bc1, s2x2bar_fs, N, p2);
    s2tilde_ameff2_bc1_fs(i) = vc_ameff2_logit(X2_y0, X2_y1, deltatilde1, Htilde_bc1, p2, N*T);

    bias_meff3_bc1_fs = bias_meff_logit(x2bar_y0_fs(:,i), deltatilde1, biasalphatildebc1, sigma2alphatildebc1,p2,Dp,N);  
    meff3tildebc1_fs(:,i) = btildebc1(:,i) * sum(logpdf(x2bar_y0_fs(:,i)' * btildebc1(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)))/N - bias_meff3_bc1_fs/T;
    bias_ameff3_bc1_fs = bias_ameff_logit(mutildebc1_y0, deltatilde1, biasalphatildebc1, sigma2alphatildebc1, phialphatildebc1, p2 ,Dp, N*T);
    ameff3tildebc1_fs(:,i) = btildebc1(:,i) * sum(logpdf(X2_y0*deltatilde1))/(N*T) - bias_ameff3_bc1_fs/T;
    Htilde_meff3_bc1_fs = vc_meff_logit(d, x2bar_y0_fs(:,i), deltatilde1, Htilde_bc1, s2x2bar_y0_fs, N, p2);
    s2tilde_meff3_bc1_fs(:,i) = diag(Htilde_meff3_bc1_fs);
    Htilde_ameff3_bc1_fs = vc_ameff_logit(d, X2_y0, deltatilde1, Htilde_bc1, p2, N*T);
    s2tilde_ameff3_bc1_fs(:,i) = diag(Htilde_ameff3_bc1_fs);

    
    bias_meff4_bc1_fs = bias_meff_logit(x2bar_y1_fs(:,i), deltatilde1, biasalphatildebc1, sigma2alphatildebc1,p2,Dp,N);  
    meff4tildebc1_fs(:,i) = btildebc1(:,i) * sum(logpdf(x2bar_y1_fs(:,i)' * btildebc1(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)))/N - bias_meff4_bc1_fs/T;
    bias_ameff4_bc1_fs = bias_ameff_logit(mutildebc1_y1, deltatilde1, biasalphatildebc1, sigma2alphatildebc1, phialphatildebc1, p2 ,Dp, N*T);
    ameff4tildebc1_fs(:,i) = btildebc1(:,i) * sum(logpdf(X2_y1*deltatilde1))/(N*T) - bias_ameff4_bc1_fs/T;
    Htilde_meff4_bc1_fs = vc_meff_logit(d, x2bar_y1_fs(:,i), deltatilde1, Htilde_bc1, s2x2bar_y1_fs, N, p2);
    s2tilde_meff4_bc1_fs(:,i) = diag(Htilde_meff4_bc1_fs);
    Htilde_ameff4_bc1_fs = vc_ameff_logit(d, X2_y1, deltatilde1, Htilde_bc1, p2, N*T);
    s2tilde_ameff4_bc1_fs(:,i) = diag(Htilde_ameff4_bc1_fs);

    mefftilde1_fs(:,i) = btildebc1(:,i) * sum(logpdf(x2bar_y0(:,i)' * btildebc1(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)))/N ;
    amefftilde1_fs(:,i) = btildebc1(:,i) * sum(logpdf(X2*deltatilde1))/(N*T);
    meff2tilde1_fs(i) = sum(logcdf(x2bar_y1_fs(:,i)' * btildebc1(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)) - ...
        logcdf(x2bar_y0_fs(:,i)' * btildebc1(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)))/N;
    ameff2tilde1_fs(i) = sum(logcdf(mutildebc1_y1) - logcdf(mutildebc1_y0))/(N*T);
    
% ANALYTICAL-M BC MLE LOGIT;    
    biasbetatildebc2(:,i) = bias_beta_logit(d,X2,deltatilde,Np,Dp);
%    BIAS2_2(:,i) = bias_beta(d,X2,delta,Np,Dp);
    btildebc2(:,i) = btilde1(:,i) - (1/T)*biasbetatildebc2(:,i);
    b2 = btildebc2(:,i);
    deltilde2 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','logit','off',X2(:,1:p2)*b2,[ ] ,'off');
    deltatilde2 = [btildebc2(:,i);deltilde2];

    Htilde_bc2 = avc_logit(d,X2,[b2;deltilde2],Dp);
    s2tilde_bc2(:,i) = diag(Htilde_bc2(1:p2,1:p2));

    biasalphatildebc2 = bias_alpha_logit(d,X2,[btildebc2(:,i);deltilde2],Dp);
    sigma2alphatildebc2 = sigma2_alpha_logit(d,X2,[btildebc2(:,i);deltilde2],Dp);
    phialphatildebc2 = phi_alpha_logit(d,X2,[btildebc2(:,i);deltilde2],Dp);

    mutildebc2 = x2p*btildebc2(:,i) + kron(deltilde2,ones(T,1));
    mutildebc2_y0 = x2p_y0*btildebc2(:,i) + kron(deltilde2,ones(T,1));
    mutildebc2_y1 = x2p_y1*btildebc2(:,i) + kron(deltilde2,ones(T,1));
    
    bias_meff_bc2 = bias_meff_logit(x2bar(:,i), deltatilde2, biasalphatildebc2, sigma2alphatildebc2,p2,Dp, Np);  
    mefftildebc2(:,i) = btildebc2(:,i) * mean(logpdf(x2bar(:,i)' * btildebc2(:,i) + deltatilde2((p2+1):size(deltatilde2,1),1))) - bias_meff_bc2/T;
    bias_ameff_bc2 = bias_ameff_logit(mutildebc2, deltatilde2, biasalphatildebc2, sigma2alphatildebc2, phialphatildebc2, p2 ,Dp, Np*T);
    amefftildebc2(:,i) = btildebc2(:,i) * mean(logpdf(X2*deltatilde2)) - bias_ameff_bc2/T;
    Htilde_meff_bc2 = vc_meff_logit(d, x2bar(:,i), deltatilde2, Htilde_bc2, s2x2bar, Np, p2);
    s2tilde_meff_bc2(:,i) = diag(Htilde_meff_bc2);
    Htilde_ameff_bc2 = vc_ameff_logit(d, X2, deltatilde2, Htilde_bc2, p2, Np*T);
    s2tilde_ameff_bc2(:,i) = diag(Htilde_ameff_bc2);

    bias_meff_bc2_fs = bias_meff_logit(x2bar_fs(:,i), deltatilde2, biasalphatildebc2, sigma2alphatildebc2,p2,Dp,N);  
    mefftildebc2_fs(:,i) = btildebc2(:,i) * sum(logpdf(x2bar(:,i)' * btildebc2(:,i) + deltatilde2((p2+1):size(deltatilde2,1),1)))/N - bias_meff_bc2_fs/T;
    bias_ameff_bc2_fs = bias_ameff_logit(mutildebc2, deltatilde2, biasalphatildebc2, sigma2alphatildebc2, phialphatildebc2, p2 ,Dp, N*T);
    amefftildebc2_fs(:,i) = btildebc2(:,i) * sum(logpdf(X2*deltatilde2))/(N*T) - bias_ameff_bc2_fs/T;
    Htilde_meff_bc2_fs = vc_meff_logit(d, x2bar_fs(:,i), deltatilde2, Htilde_bc2, s2x2bar_fs, N, p2);
    s2tilde_meff_bc2_fs(:,i) = diag(Htilde_meff_bc2_fs);
    Htilde_ameff_bc2_fs = vc_ameff_logit(d, X2, deltatilde2, Htilde_bc2, p2, N*T);
    s2tilde_ameff_bc2_fs(:,i) = diag(Htilde_ameff_bc2_fs);
    
    bias_meff2_bc2_fs = bias_meff2_logit(x2bar_y0_fs(:,i), x2bar_y1_fs(:,i), deltatilde2, biasalphatildebc2, sigma2alphatildebc2,p2,Dp,N);  
    meff2tildebc2_fs(i) = sum(logcdf(x2bar_y1_fs(:,i)' * btildebc2(:,i) + deltatilde2((p2+1):size(deltatilde2,1),1)) - ...
        logcdf(x2bar_y0_fs(:,i)' * btildebc2(:,i) + deltatilde2((p2+1):size(deltatilde2,1),1)))/N - bias_meff2_bc2_fs/T;
    bias_ameff2_bc2_fs = bias_ameff2_logit(mutildebc2_y0, mutildebc2_y1, deltatilde2, biasalphatildebc2, sigma2alphatildebc2, phialphatildebc2, p2 ,Dp, N*T);
    ameff2tildebc2_fs(i) = sum(logcdf(mutildebc2_y1) - logcdf(mutildebc2_y0))/(N*T) - bias_ameff2_bc2_fs/T;
    s2tilde_meff2_bc2_fs(i) = vc_meff2_logit(x2bar_y0_fs(:,i),x2bar_y1_fs(:,i), deltatilde2, Htilde_bc2, s2x2bar_fs, N, p2);
    s2tilde_ameff2_bc2_fs(i) = vc_ameff2_logit(X2_y0, X2_y1, deltatilde2, Htilde_bc2, p2, N*T);

    bias_meff3_bc2_fs = bias_meff_logit(x2bar_y0_fs(:,i), deltatilde1, biasalphatildebc2, sigma2alphatildebc2,p2,Dp,N);  
    meff3tildebc2_fs(:,i) = btildebc2(:,i) * sum(logpdf(x2bar_y0_fs(:,i)' * btildebc2(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)))/N - bias_meff3_bc2_fs/T;
    bias_ameff3_bc2_fs = bias_ameff_logit(mutildebc2_y0, deltatilde1, biasalphatildebc2, sigma2alphatildebc2, phialphatildebc2, p2 ,Dp, N*T);
    ameff3tildebc2_fs(:,i) = btildebc2(:,i) * sum(logpdf(X2_y0*deltatilde1))/(N*T) - bias_ameff3_bc2_fs/T;
    Htilde_meff3_bc2_fs = vc_meff_logit(d, x2bar_y0_fs(:,i), deltatilde1, Htilde_bc2, s2x2bar_y0_fs, N, p2);
    s2tilde_meff3_bc2_fs(:,i) = diag(Htilde_meff3_bc2_fs);
    Htilde_ameff3_bc2_fs = vc_ameff_logit(d, X2_y0, deltatilde1, Htilde_bc2, p2, N*T);
    s2tilde_ameff3_bc2_fs(:,i) = diag(Htilde_ameff3_bc2_fs);

    
    bias_meff4_bc2_fs = bias_meff_logit(x2bar_y1_fs(:,i), deltatilde1, biasalphatildebc2, sigma2alphatildebc2,p2,Dp,N);  
    meff4tildebc2_fs(:,i) = btildebc2(:,i) * sum(logpdf(x2bar_y1_fs(:,i)' * btildebc2(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)))/N - bias_meff4_bc2_fs/T;
    bias_ameff4_bc2_fs = bias_ameff_logit(mutildebc2_y1, deltatilde1, biasalphatildebc2, sigma2alphatildebc2, phialphatildebc2, p2 ,Dp, N*T);
    ameff4tildebc2_fs(:,i) = btildebc2(:,i) * sum(logpdf(X2_y1*deltatilde1))/(N*T) - bias_ameff4_bc2_fs/T;
    Htilde_meff4_bc2_fs = vc_meff_logit(d, x2bar_y1_fs(:,i), deltatilde1, Htilde_bc2, s2x2bar_y1_fs, N, p2);
    s2tilde_meff4_bc2_fs(:,i) = diag(Htilde_meff4_bc2_fs);
    Htilde_ameff4_bc2_fs = vc_ameff_logit(d, X2_y1, deltatilde1, Htilde_bc2, p2, N*T);
    s2tilde_ameff4_bc2_fs(:,i) = diag(Htilde_ameff4_bc2_fs);

    mefftilde2_fs(:,i) = btildebc2(:,i) * sum(logpdf(x2bar_y0(:,i)' * btildebc2(:,i) + deltatilde2((p2+1):size(deltatilde2,1),1)))/N ;
    amefftilde2_fs(:,i) = btildebc2(:,i) * sum(logpdf(X2*deltatilde2))/(N*T);
    meff2tilde2_fs(i) = sum(logcdf(x2bar_y1_fs(:,i)' * btildebc2(:,i) + deltatilde2((p2+1):size(deltatilde2,1),1)) - ...
        logcdf(x2bar_y0_fs(:,i)' * btildebc2(:,i) + deltatilde2((p2+1):size(deltatilde2,1),1)))/N;
    ameff2tilde2_fs(i) = sum(logcdf(mutildebc2_y1) - logcdf(mutildebc2_y0))/(N*T);
    
% ANALYTICAL 2 BC MLE LOGIT;    
    biasbetatildebc3(:,i) = bias_beta_logit_mle2(d,X2,deltatilde,Np,Dp);
    btildebc3(:,i) = btilde1(:,i) - (1/T)*biasbetatildebc3(:,i);
    b3 = btildebc3(:,i);
    deltilde3 = glmfit1(X2(:,(p2+1):size(X2,2)),[d ones(size(d,1),1)],'binomial','logit','off',X2(:,1:p2)*b3,[ ] ,'off');
    deltatilde3 = [btildebc3(:,i);deltilde3];

    Htilde_bc3 = avc_logit(d,X2,[b3;deltilde3],Dp);
    s2tilde_bc3(:,i) = diag(Htilde_bc3(1:p2,1:p2));

    biasalphatildebc3 = bias_alpha_logit_mle2(d,X2,[btildebc3(:,i);deltilde3],Dp);
    sigma2alphatildebc3 = sigma2_alpha_logit_mle2(d,X2,[btildebc3(:,i);deltilde3],Dp);
    phialphatildebc3 = phi_alpha_logit_mle2(d,X2,[btildebc3(:,i);deltilde3],Dp);

    mutildebc3 = x2p*btildebc3(:,i) + kron(deltilde3,ones(T,1));
    mutildebc3_y0 = x2p_y0*btildebc3(:,i) + kron(deltilde3,ones(T,1));
    mutildebc3_y1 = x2p_y1*btildebc3(:,i) + kron(deltilde3,ones(T,1));
    
    bias_meff_bc3 = bias_meff_logit(x2bar(:,i), deltatilde3, biasalphatildebc3, sigma2alphatildebc3,p2,Dp, Np);  
    mefftildebc3(:,i) = btildebc3(:,i) * mean(logpdf(x2bar(:,i)' * btildebc3(:,i) + deltatilde3((p2+1):size(deltatilde3,1),1))) - bias_meff_bc3/T;
    bias_ameff_bc3 = bias_ameff_logit(mutildebc3, deltatilde3, biasalphatildebc3, sigma2alphatildebc3, phialphatildebc3, p2 ,Dp, Np*T);
    amefftildebc3(:,i) = btildebc3(:,i) * mean(logpdf(X2*deltatilde3)) - bias_ameff_bc3/T;
    Htilde_meff_bc3 = vc_meff_logit(d, x2bar(:,i), deltatilde3, Htilde_bc3, s2x2bar, Np, p2);
    s2tilde_meff_bc3(:,i) = diag(Htilde_meff_bc3);
    Htilde_ameff_bc3 = vc_ameff_logit(d, X2, deltatilde3, Htilde_bc3, p2, Np*T);
    s2tilde_ameff_bc3(:,i) = diag(Htilde_ameff_bc3);

    bias_meff_bc3_fs = bias_meff_logit(x2bar_fs(:,i), deltatilde3, biasalphatildebc3, sigma2alphatildebc3,p2,Dp,N);  
    mefftildebc3_fs(:,i) = btildebc3(:,i) * sum(logpdf(x2bar(:,i)' * btildebc3(:,i) + deltatilde3((p2+1):size(deltatilde3,1),1)))/N - bias_meff_bc3_fs/T;
    bias_ameff_bc3_fs = bias_ameff_logit(mutildebc3, deltatilde3, biasalphatildebc3, sigma2alphatildebc3, phialphatildebc3, p2 ,Dp, N*T);
    amefftildebc3_fs(:,i) = btildebc3(:,i) * sum(logpdf(X2*deltatilde3))/(N*T) - bias_ameff_bc3_fs/T;
    Htilde_meff_bc3_fs = vc_meff_logit(d, x2bar_fs(:,i), deltatilde3, Htilde_bc3, s2x2bar_fs, N, p2);
    s2tilde_meff_bc3_fs(:,i) = diag(Htilde_meff_bc3_fs);
    Htilde_ameff_bc3_fs = vc_ameff_logit(d, X2, deltatilde3, Htilde_bc3, p2, N*T);
    s2tilde_ameff_bc3_fs(:,i) = diag(Htilde_ameff_bc3_fs);

    bias_meff2_bc3_fs = bias_meff2_logit(x2bar_y0_fs(:,i), x2bar_y1_fs(:,i), deltatilde3, biasalphatildebc3, sigma2alphatildebc3,p2,Dp,N);  
    meff2tildebc3_fs(i) = sum(logcdf(x2bar_y1_fs(:,i)' * btildebc3(:,i) + deltatilde3((p2+1):size(deltatilde3,1),1)) - ...
        logcdf(x2bar_y0_fs(:,i)' * btildebc3(:,i) + deltatilde3((p2+1):size(deltatilde3,1),1)))/N - bias_meff2_bc3_fs/T;
    bias_ameff2_bc3_fs = bias_ameff2_logit(mutildebc3_y0, mutildebc3_y1, deltatilde3, biasalphatildebc3, sigma2alphatildebc3, phialphatildebc3, p2 ,Dp, N*T);
    ameff2tildebc3_fs(i) = sum(logcdf(mutildebc3_y1) - logcdf(mutildebc3_y0))/(N*T) - bias_ameff2_bc3_fs/T;
    s2tilde_meff2_bc3_fs(i) = vc_meff2_logit(x2bar_y0_fs(:,i),x2bar_y1_fs(:,i), deltatilde3, Htilde_bc3, s2x2bar_fs, N, p2);
    s2tilde_ameff2_bc3_fs(i) = vc_ameff2_logit(X2_y0, X2_y1, deltatilde3, Htilde_bc3, p2, N*T);

    bias_meff3_bc3_fs = bias_meff_logit(x2bar_y0_fs(:,i), deltatilde1, biasalphatildebc3, sigma2alphatildebc3,p2,Dp,N);  
    meff3tildebc3_fs(:,i) = btildebc3(:,i) * sum(logpdf(x2bar_y0_fs(:,i)' * btildebc3(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)))/N - bias_meff3_bc3_fs/T;
    bias_ameff3_bc3_fs = bias_ameff_logit(mutildebc3_y0, deltatilde1, biasalphatildebc3, sigma2alphatildebc3, phialphatildebc3, p2 ,Dp, N*T);
    ameff3tildebc3_fs(:,i) = btildebc3(:,i) * sum(logpdf(X2_y0*deltatilde1))/(N*T) - bias_ameff3_bc3_fs/T;
    Htilde_meff3_bc3_fs = vc_meff_logit(d, x2bar_y0_fs(:,i), deltatilde1, Htilde_bc3, s2x2bar_y0_fs, N, p2);
    s2tilde_meff3_bc3_fs(:,i) = diag(Htilde_meff3_bc3_fs);
    Htilde_ameff3_bc3_fs = vc_ameff_logit(d, X2_y0, deltatilde1, Htilde_bc3, p2, N*T);
    s2tilde_ameff3_bc3_fs(:,i) = diag(Htilde_ameff3_bc3_fs);

    
    bias_meff4_bc3_fs = bias_meff_logit(x2bar_y1_fs(:,i), deltatilde1, biasalphatildebc3, sigma2alphatildebc3,p2,Dp,N);  
    meff4tildebc3_fs(:,i) = btildebc3(:,i) * sum(logpdf(x2bar_y1_fs(:,i)' * btildebc3(:,i) + deltatilde1((p2+1):size(deltatilde1,1),1)))/N - bias_meff4_bc3_fs/T;
    bias_ameff4_bc3_fs = bias_ameff_logit(mutildebc3_y1, deltatilde1, biasalphatildebc3, sigma2alphatildebc3, phialphatildebc3, p2 ,Dp, N*T);
    ameff4tildebc3_fs(:,i) = btildebc3(:,i) * sum(logpdf(X2_y1*deltatilde1))/(N*T) - bias_ameff4_bc3_fs/T;
    Htilde_meff4_bc3_fs = vc_meff_logit(d, x2bar_y1_fs(:,i), deltatilde1, Htilde_bc3, s2x2bar_y1_fs, N, p2);
    s2tilde_meff4_bc3_fs(:,i) = diag(Htilde_meff4_bc3_fs);
    Htilde_ameff4_bc3_fs = vc_ameff_logit(d, X2_y1, deltatilde1, Htilde_bc3, p2, N*T);
    s2tilde_ameff4_bc3_fs(:,i) = diag(Htilde_ameff4_bc3_fs);

    mefftilde3_fs(:,i) = btildebc3(:,i) * sum(logpdf(x2bar_y0(:,i)' * btildebc3(:,i) + deltatilde3((p2+1):size(deltatilde3,1),1)))/N ;
    amefftilde3_fs(:,i) = btildebc3(:,i) * sum(logpdf(X2*deltatilde3))/(N*T);
    meff2tilde3_fs(i) = sum(logcdf(x2bar_y1_fs(:,i)' * btildebc3(:,i) + deltatilde3((p2+1):size(deltatilde3,1),1)) - ...
        logcdf(x2bar_y0_fs(:,i)' * btildebc3(:,i) + deltatilde3((p2+1):size(deltatilde3,1),1)))/N;
    ameff2tilde3_fs(i) = sum(logcdf(mutildebc3_y1) - logcdf(mutildebc3_y0))/(N*T);
    
  

end
toc,


% NORMALIZATION FOR THE LOGIT;

btilde1 = clog*btilde1;
btildebc1 = clog*btildebc1;
btildebc2 = clog*btildebc2;
btildebc3 = clog*btildebc3;

s2tilde_mle = (clog^2)*s2tilde_mle;
s2tilde_bc1 = (clog^2)*s2tilde_bc1;
s2tilde_bc2 = (clog^2)*s2tilde_bc2;
s2tilde_bc3 = (clog^2)*s2tilde_bc3;


disp(size(bhat1));


disp('Table 1a: Coefficients beta1');
full([mean(bhat1(1,:))      median(bhat1(1,:))        sqrt(s2hat_mle(1,:))  ;...
    mean(bhatbc1(1,:))      median(bhatbc1(1,:))      sqrt(s2hat_bc1(1,:))  ;...
    mean(bhatbc2(1,:))      median(bhatbc2(1,:))      sqrt(s2hat_bc2(1,:))  ;...
    mean(bhatbc3(1,:))      median(bhatbc3(1,:))      sqrt(s2hat_bc3(1,:))  ; ...
    mean(bhatbc4(1,:))      median(bhatbc4(1,:))      sqrt(s2hat_bc4(1,:))  ; ...
    mean(btilde1(1,:))      median(btilde1(1,:))      sqrt(s2tilde_mle(1,:)) ;...
    mean(btildebc1(1,:))    median(btildebc1(1,:))    sqrt(s2tilde_bc1(1,:)) ;...
    mean(btildebc2(1,:))    median(btildebc2(1,:))    sqrt(s2tilde_bc2(1,:))  ;...
    mean(btildebc3(1,:))    median(btildebc3(1,:))    sqrt(s2tilde_bc3(1,:)) ])

disp('Table 1b: Coefficients beta2');
full([mean(bhat1(2,:))      median(bhat1(2,:))        sqrt(s2hat_mle(2,:))  ;...
    mean(bhatbc1(2,:))      median(bhatbc1(2,:))      sqrt(s2hat_bc1(2,:))  ;...
    mean(bhatbc2(2,:))      median(bhatbc2(2,:))      sqrt(s2hat_bc2(2,:))  ;...
    mean(bhatbc3(2,:))      median(bhatbc3(2,:))      sqrt(s2hat_bc3(2,:))  ; ...
    mean(bhatbc4(2,:))      median(bhatbc4(2,:))      sqrt(s2hat_bc4(2,:))  ; ...
    mean(btilde1(2,:))      median(btilde1(2,:))      sqrt(s2tilde_mle(2,:)) ;...
    mean(btildebc1(2,:))    median(btildebc1(2,:))    sqrt(s2tilde_bc1(2,:)) ;...
    mean(btildebc2(2,:))    median(btildebc2(2,:))    sqrt(s2tilde_bc2(2,:))  ;...
    mean(btildebc3(2,:))    median(btildebc3(2,:))    sqrt(s2tilde_bc3(2,:)) ])

disp('Table 1b: Coefficients beta3');
full([mean(bhat1(3,:))      median(bhat1(3,:))        sqrt(s2hat_mle(3,:))  ;...
    mean(bhatbc1(3,:))      median(bhatbc1(3,:))      sqrt(s2hat_bc1(3,:))  ;...
    mean(bhatbc2(3,:))      median(bhatbc2(3,:))      sqrt(s2hat_bc2(3,:))  ;...
    mean(bhatbc3(3,:))      median(bhatbc3(3,:))      sqrt(s2hat_bc3(3,:))  ; ...
    mean(bhatbc4(3,:))      median(bhatbc4(3,:))      sqrt(s2hat_bc4(3,:))  ; ...
    mean(btilde1(3,:))      median(btilde1(3,:))      sqrt(s2tilde_mle(3,:)) ;...
    mean(btildebc1(3,:))    median(btildebc1(3,:))    sqrt(s2tilde_bc1(3,:)) ;...
    mean(btildebc2(3,:))    median(btildebc2(3,:))    sqrt(s2tilde_bc2(3,:))  ;...
    mean(btildebc3(3,:))    median(btildebc3(3,:))    sqrt(s2tilde_bc3(3,:)) ])

disp('Table 1b: Coefficients beta4');
full([mean(bhat1(4,:))      median(bhat1(4,:))        sqrt(s2hat_mle(4,:))  ;...
    mean(bhatbc1(4,:))      median(bhatbc1(4,:))      sqrt(s2hat_bc1(4,:))  ;...
    mean(bhatbc2(4,:))      median(bhatbc2(4,:))      sqrt(s2hat_bc2(4,:))  ;...
    mean(bhatbc3(4,:))      median(bhatbc3(4,:))      sqrt(s2hat_bc3(4,:))  ; ...
    mean(bhatbc4(4,:))      median(bhatbc4(4,:))      sqrt(s2hat_bc4(4,:))  ; ...
    mean(btilde1(4,:))      median(btilde1(4,:))      sqrt(s2tilde_mle(4,:)) ;...
    mean(btildebc1(4,:))    median(btildebc1(4,:))    sqrt(s2tilde_bc1(4,:)) ;...
    mean(btildebc2(4,:))    median(btildebc2(4,:))    sqrt(s2tilde_bc2(4,:))  ;...
    mean(btildebc3(4,:))    median(btildebc3(4,:))    sqrt(s2tilde_bc3(4,:)) ])

disp('Table 1b: Coefficients beta5');
full([mean(bhat1(5,:))      median(bhat1(5,:))        sqrt(s2hat_mle(5,:))  ;...
    mean(bhatbc1(5,:))      median(bhatbc1(5,:))      sqrt(s2hat_bc1(5,:))  ;...
    mean(bhatbc2(5,:))      median(bhatbc2(5,:))      sqrt(s2hat_bc2(5,:))  ;...
    mean(bhatbc3(5,:))      median(bhatbc3(5,:))      sqrt(s2hat_bc3(5,:))  ; ...
    mean(bhatbc4(5,:))      median(bhatbc4(5,:))      sqrt(s2hat_bc4(5,:))  ; ...
    mean(btilde1(5,:))      median(btilde1(5,:))      sqrt(s2tilde_mle(5,:)) ;...
    mean(btildebc1(5,:))    median(btildebc1(5,:))    sqrt(s2tilde_bc1(5,:)) ;...
    mean(btildebc2(5,:))    median(btildebc2(5,:))    sqrt(s2tilde_bc2(5,:))  ;...
    mean(btildebc3(5,:))    median(btildebc3(5,:))    sqrt(s2tilde_bc3(5,:)) ])

disp('Table 1b: Coefficients beta6');
full([mean(bhat1(6,:))      median(bhat1(6,:))        sqrt(s2hat_mle(6,:))  ;...
    mean(bhatbc1(6,:))      median(bhatbc1(6,:))      sqrt(s2hat_bc1(6,:))  ;...
    mean(bhatbc2(6,:))      median(bhatbc2(6,:))      sqrt(s2hat_bc2(6,:))  ;...
    mean(bhatbc3(6,:))      median(bhatbc3(6,:))      sqrt(s2hat_bc3(6,:))  ; ...
    mean(bhatbc4(6,:))      median(bhatbc4(6,:))      sqrt(s2hat_bc4(6,:))  ; ...
    mean(btilde1(6,:))      median(btilde1(6,:))      sqrt(s2tilde_mle(6,:)) ;...
    mean(btildebc1(6,:))    median(btildebc1(6,:))    sqrt(s2tilde_bc1(6,:)) ;...
    mean(btildebc2(6,:))    median(btildebc2(6,:))    sqrt(s2tilde_bc2(6,:))  ;...
    mean(btildebc3(6,:))    median(btildebc3(6,:))    sqrt(s2tilde_bc3(6,:)) ])




disp('Table 10a: Average Marginal Effects beta1 (FS)');
100*full([mean(ameffhat_fs(1,:))      sqrt(s2hat_ameff_mle_fs(1,:));...
    mean(ameffhatbc1_fs(1,:))     sqrt(s2hat_ameff_bc1_fs(1,:));...
    mean(ameffhatbc2_fs(1,:))     sqrt(s2hat_ameff_bc2_fs(1,:));...
    mean(ameffhatbc3_fs(1,:))     sqrt(s2hat_ameff_bc3_fs(1,:)); ...
    mean(ameffhatbc4_fs(1,:))     sqrt(s2hat_ameff_bc4_fs(1,:)); ...
    mean(amefftilde_fs(1,:))      sqrt(s2tilde_ameff_mle_fs(1,:));...
    mean(amefftildebc1_fs(1,:))   sqrt(s2tilde_ameff_bc1_fs(1,:));...
    mean(amefftildebc2_fs(1,:))   sqrt(s2tilde_ameff_bc2_fs(1,:));...
    mean(amefftildebc3_fs(1,:))   sqrt(s2tilde_ameff_bc3_fs(1,:)); ...
    mean(ameffhatolsen_fs(1,:))   sqrt(s2hat_ameff_olsen_fs(1,:));...
    mean(ameffhatolsenbc_fs(1,:)) sqrt(s2hat_ameff_olsenbc_fs(1,:));...
    mean(ameffhatlpm_fs(1,:))   sqrt(s2hat_ameff_lpm_fs(1,:));...
    mean(ameffhatlpmbc_fs(1,:)) sqrt(s2hat_ameff_lpmbc_fs(1,:))])

disp('Table 10b: Average Marginal Effects beta2 (FS)');
100*full([mean(ameffhat_fs(2,:))      sqrt(s2hat_ameff_mle_fs(2,:));...
    mean(ameffhatbc1_fs(2,:))     sqrt(s2hat_ameff_bc1_fs(2,:));...
    mean(ameffhatbc2_fs(2,:))     sqrt(s2hat_ameff_bc2_fs(2,:));...
    mean(ameffhatbc3_fs(2,:))     sqrt(s2hat_ameff_bc3_fs(2,:)); ...
    mean(ameffhatbc4_fs(2,:))     sqrt(s2hat_ameff_bc4_fs(2,:)); ...
    mean(amefftilde_fs(2,:))      sqrt(s2tilde_ameff_mle_fs(2,:));...
    mean(amefftildebc1_fs(2,:))   sqrt(s2tilde_ameff_bc1_fs(2,:));...
    mean(amefftildebc2_fs(2,:))   sqrt(s2tilde_ameff_bc2_fs(2,:));...
    mean(amefftildebc3_fs(2,:))   sqrt(s2tilde_ameff_bc3_fs(2,:)); ...
    mean(ameffhatolsen_fs(2,:))   sqrt(s2hat_ameff_olsen_fs(2,:));...
    mean(ameffhatolsenbc_fs(2,:)) sqrt(s2hat_ameff_olsenbc_fs(2,:));...
    mean(ameffhatlpm_fs(2,:))   sqrt(s2hat_ameff_lpm_fs(2,:));...
    mean(ameffhatlpmbc_fs(2,:)) sqrt(s2hat_ameff_lpmbc_fs(2,:))])

disp('Table 10b: Average Marginal Effects beta3 (FS)');
100*full([mean(ameffhat_fs(3,:))      sqrt(s2hat_ameff_mle_fs(3,:));...
    mean(ameffhatbc1_fs(3,:))     sqrt(s2hat_ameff_bc1_fs(3,:));...
    mean(ameffhatbc2_fs(3,:))     sqrt(s2hat_ameff_bc2_fs(3,:));...
    mean(ameffhatbc3_fs(3,:))     sqrt(s2hat_ameff_bc3_fs(3,:)); ...
    mean(ameffhatbc4_fs(3,:))     sqrt(s2hat_ameff_bc4_fs(3,:)); ...
    mean(amefftilde_fs(3,:))      sqrt(s2tilde_ameff_mle_fs(3,:));...
    mean(amefftildebc1_fs(3,:))   sqrt(s2tilde_ameff_bc1_fs(3,:));...
    mean(amefftildebc2_fs(3,:))   sqrt(s2tilde_ameff_bc2_fs(3,:));...
    mean(amefftildebc3_fs(3,:))   sqrt(s2tilde_ameff_bc3_fs(3,:)); ...
    mean(ameffhatolsen_fs(3,:))   sqrt(s2hat_ameff_olsen_fs(3,:));...
    mean(ameffhatolsenbc_fs(3,:)) sqrt(s2hat_ameff_olsenbc_fs(3,:));...
    mean(ameffhatlpm_fs(3,:))   sqrt(s2hat_ameff_lpm_fs(3,:));...
    mean(ameffhatlpmbc_fs(3,:)) sqrt(s2hat_ameff_lpmbc_fs(3,:))])

disp('Table 10b: Average Marginal Effects beta4 (FS)');
100*full([mean(ameffhat_fs(4,:))      sqrt(s2hat_ameff_mle_fs(4,:));...
    mean(ameffhatbc1_fs(4,:))     sqrt(s2hat_ameff_bc1_fs(4,:));...
    mean(ameffhatbc2_fs(4,:))     sqrt(s2hat_ameff_bc2_fs(4,:));...
    mean(ameffhatbc3_fs(4,:))     sqrt(s2hat_ameff_bc3_fs(4,:)); ...
    mean(ameffhatbc4_fs(4,:))     sqrt(s2hat_ameff_bc4_fs(4,:)); ...
    mean(amefftilde_fs(4,:))      sqrt(s2tilde_ameff_mle_fs(4,:));...
    mean(amefftildebc1_fs(4,:))   sqrt(s2tilde_ameff_bc1_fs(4,:));...
    mean(amefftildebc2_fs(4,:))   sqrt(s2tilde_ameff_bc2_fs(4,:));...
    mean(amefftildebc3_fs(4,:))   sqrt(s2tilde_ameff_bc3_fs(4,:)); ...
    mean(ameffhatolsen_fs(4,:))   sqrt(s2hat_ameff_olsen_fs(4,:));...
    mean(ameffhatolsenbc_fs(4,:)) sqrt(s2hat_ameff_olsenbc_fs(4,:));...
    mean(ameffhatlpm_fs(4,:))   sqrt(s2hat_ameff_lpm_fs(4,:));...
    mean(ameffhatlpmbc_fs(4,:)) sqrt(s2hat_ameff_lpmbc_fs(4,:))])

disp('Table 10b: Average Marginal Effects beta5 (FS)');
100*full([mean(ameffhat_fs(5,:))      sqrt(s2hat_ameff_mle_fs(5,:));...
    mean(ameffhatbc1_fs(5,:))     sqrt(s2hat_ameff_bc1_fs(5,:));...
    mean(ameffhatbc2_fs(5,:))     sqrt(s2hat_ameff_bc2_fs(5,:));...
    mean(ameffhatbc3_fs(5,:))     sqrt(s2hat_ameff_bc3_fs(5,:)); ...
    mean(ameffhatbc4_fs(5,:))     sqrt(s2hat_ameff_bc4_fs(5,:)); ...
    mean(amefftilde_fs(5,:))      sqrt(s2tilde_ameff_mle_fs(5,:));...
    mean(amefftildebc1_fs(5,:))   sqrt(s2tilde_ameff_bc1_fs(5,:));...
    mean(amefftildebc2_fs(5,:))   sqrt(s2tilde_ameff_bc2_fs(5,:));...
    mean(amefftildebc3_fs(5,:))   sqrt(s2tilde_ameff_bc3_fs(5,:)); ...
    mean(ameffhatolsen_fs(5,:))   sqrt(s2hat_ameff_olsen_fs(5,:));...
    mean(ameffhatolsenbc_fs(5,:)) sqrt(s2hat_ameff_olsenbc_fs(5,:));...
    mean(ameffhatlpm_fs(5,:))   sqrt(s2hat_ameff_lpm_fs(5,:));...
    mean(ameffhatlpmbc_fs(5,:)) sqrt(s2hat_ameff_lpmbc_fs(5,:))])

disp('Table 10b: Average Marginal Effects beta6 (FS)');
100*full([mean(ameffhat_fs(6,:))      sqrt(s2hat_ameff_mle_fs(6,:));...
    mean(ameffhatbc1_fs(6,:))     sqrt(s2hat_ameff_bc1_fs(6,:));...
    mean(ameffhatbc2_fs(6,:))     sqrt(s2hat_ameff_bc2_fs(6,:));...
    mean(ameffhatbc3_fs(6,:))     sqrt(s2hat_ameff_bc3_fs(6,:)); ...
    mean(ameffhatbc4_fs(6,:))     sqrt(s2hat_ameff_bc4_fs(6,:)); ...
    mean(amefftilde_fs(6,:))      sqrt(s2tilde_ameff_mle_fs(6,:));...
    mean(amefftildebc1_fs(6,:))   sqrt(s2tilde_ameff_bc1_fs(6,:));...
    mean(amefftildebc2_fs(6,:))   sqrt(s2tilde_ameff_bc2_fs(6,:));...
    mean(amefftildebc3_fs(6,:))   sqrt(s2tilde_ameff_bc3_fs(6,:)); ...
    mean(ameffhatolsen_fs(6,:))   sqrt(s2hat_ameff_olsen_fs(6,:));...
    mean(ameffhatolsenbc_fs(6,:)) sqrt(s2hat_ameff_olsenbc_fs(6,:));...
    mean(ameffhatlpm_fs(6,:))   sqrt(s2hat_ameff_lpm_fs(6,:));...
    mean(ameffhatlpmbc_fs(6,:)) sqrt(s2hat_ameff_lpmbc_fs(6,:))])


    

save z:\Marginal_effects\Applications\LFP3\results\specification3_predetermined

